#!/bin/sh
### BEGIN INIT INFO
# Provides:          teamspeak-daemon
# Required-Start:    $local_fs $remote_fs $network
# Required-Stop:     $local_fs $remote_fs $network
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: Start or stop the teamspeak-daemon.
### END INIT INFO

RUN_AS="admin:administrators"
PKG_NAME="teamspeak"
PKG_DIR="/usr/local/AppCentral/teamspeak"
CONFIG_DIR="/volume1/Public/teamspeak"
DAEMON_PACKAGE="" #change according to daemon version used
DAEMON_OPTS=" start license_accepted=1" 
PID_FILE="$CONFIG_DIR/teamspeak3-server/ts3server.pid"
DAEMON="$CONFIG_DIR/teamspeak3-server/ts3server_startscript.sh"

Update() { #Updates to defined version.
	VER=$(/bin/cat $CONFIG_DIR/update.txt)
	ARCH=$(/bin/uname -m)
	if [ "$ARCH" = "x86_64" ]; then
		URL="https://files.teamspeak-services.com/releases/server/${VER}/teamspeak3-server_linux_amd64-${VER}.tar.bz2"
	else
		URL="https://files.teamspeak-services.com/releases/server/${VER}/teamspeak3-server_linux_x86-${VER}.tar.bz2"
	fi
	cd $CONFIG_DIR
	mv $CONFIG_DIR/teamspeak3-server $CONFIG_DIR/teamspeak3-server.old
	wget -O teamspeak3-server.tar.bz2 $URL && mkdir $CONFIG_DIR/teamspeak3-server && tar -xvjf teamspeak3-server.tar.bz2 -C teamspeak3-server --strip-components=1 && mv $CONFIG_DIR/update.txt $CONFIG_DIR/installed.txt && rm -rf $CONFIG_DIR/teamspeak3-server.tar.bz2
	[ -d $CONFIG_DIR/teamspeak3-server ] || mv $CONFIG_DIR/teamspeak3-server.old $CONFIG_DIR/teamspeak3-server #If we could not download new version, revert to old.
	[ -f $CONFIG_DIR/update.txt ] && [ -d $CONFIG_DIR/teamspeak3-server.old ] && rm -rf $CONFIG_DIR/teamspeak3-server && mv $CONFIG_DIR/teamspeak3-server.old $CONFIG_DIR/teamspeak3-server #If we could not extract, revert to old.
	[ -d $CONFIG_DIR/teamspeak3-server/tsdns ] || mkdir $CONFIG_DIR/teamspeak3-server/tsdns #Make sure we can capture all backed-up settings.
	[ -d $CONFIG_DIR/teamspeak3-server.old ] && mv $CONFIG_DIR/teamspeak3-server.old/licensekey.dat $CONFIG_DIR/teamspeak3-server/
	[ -d $CONFIG_DIR/teamspeak3-server.old ] && mv $CONFIG_DIR/teamspeak3-server.old/query_ip_whitelist.txt $CONFIG_DIR/teamspeak3-server/
	[ -d $CONFIG_DIR/teamspeak3-server.old ] && mv $CONFIG_DIR/teamspeak3-server.old/query_ip_blacklist.txt $CONFIG_DIR/teamspeak3-server/
	[ -d $CONFIG_DIR/teamspeak3-server.old ] && mv $CONFIG_DIR/teamspeak3-server.old/files $CONFIG_DIR/teamspeak3-server/
	[ -d $CONFIG_DIR/teamspeak3-server.old ] && mv $CONFIG_DIR/teamspeak3-server.old/ts3server.sqlitedb $CONFIG_DIR/teamspeak3-server/
	[ -d $CONFIG_DIR/teamspeak3-server.old ] && mv $CONFIG_DIR/teamspeak3-server.old/*.ini $CONFIG_DIR/teamspeak3-server/
	[ -d $CONFIG_DIR/teamspeak3-server.old ] && mv $CONFIG_DIR/teamspeak3-server.old/tsdns/tsdns_settings.ini $CONFIG_DIR/teamspeak3-server/tsdns/
	[ -d $CONFIG_DIR/teamspeak3-server.old ] && [ -d $CONFIG_DIR/teamspeak3-server ] && rm -rf $CONFIG_DIR/teamspeak3-server.old
}

case "$1" in
  start)
	/bin/echo "Starting PKG_NAME... "
	[ -L $CONFIG_DIR ] && /bin/rm $CONFIG_DIR  # check for sym-link and remove it.
	[ -d $CONFIG_DIR ] || /bin/mkdir $CONFIG_DIR
	[ -d ${PKG_DIR}/config/teamspeak3-server ] && /bin/mv ${PKG_DIR}/config/* $CONFIG_DIR && /bin/rm ${PKG_DIR}/config
	#chmod
	[ -f $CONFIG_DIR/installed.txt ] || /bin/cp -rf $PKG_DIR/update.txt $CONFIG_DIR
	[ -f $CONFIG_DIR/update.txt ] && Update
	/bin/chown -R $RUN_AS /run/shm
	/bin/chown -R $RUN_AS $PKG_DIR
	/bin/chown -R $RUN_AS $CONFIG_DIR
	/bin/chmod 777 $DAEMON
	sed -i 's!-p\ ${PID}!|\ grep\ ${PID}\ |\ grep\ -v\ grep!g' $DAEMON
		
	/bin/echo "Starting TeamSpeak Server daemon... "
	/sbin/start-stop-daemon -S -n $PKG_NAME -p $PID_FILE -c $RUN_AS -x ${DAEMON} --${DAEMON_OPTS}
	RETVAL=$?
  ;;
	
  stop)
	/bin/echo "Shutting down $PKG_NAME... "
	if [ -f $PID_FILE ] && /sbin/start-stop-daemon -K --test -q -p $PID_FILE; then
		#grab pid from pid file
		Pid=$(/bin/cat $PID_FILE)
		i=0
		/sbin/start-stop-daemon -K -q -p $PID_FILE
		/bin/echo -n " Waiting for ${PKG_NAME} to shut down: "
		while [ -d /proc/$Pid ]; do
			sleep 1
			let i+=1
			/bin/echo -n "$i, "
			if [ $i = 45 ]; then
				/bin/echo -n " Tired of waiting, killing ${PKG_NAME} now"
				/bin/kill -9 $Pid
				/bin/rm -f $PID_FILE
				/bin/echo " Done ($(/bin/date))"
				exit 1
			fi
		done
		/bin/rm -f $PID_FILE
		/bin/echo "Done ($(/bin/date))"
	else
		/bin/echo "${PKG_NAME} is not running? ($(/bin/date))"
	fi
	/bin/sleep 1
	RETVAL=$?
	/bin/sleep 3
  ;;
		
  restart)
		$0 stop
		/bin/sleep 10
		$0 start
		RETVAL=$?
  ;;
  *)
		/bin/echo "Usage: $0 {start|stop|restart}"
esac

exit 0